@@ -59,7 +59,7 @@ class ISchedulerTaskHistoryInfo(Interface):
                     required=True)
 
     status = Choice(title=_("Execution status"),
-                    values=('OK', 'Warning', 'Error'))
+                    values=('OK', 'Warning', 'Error', 'Empty'))
 
     report = Text(title=_("Execution report"),
                   required=True)
@@ -94,8 +94,18 @@ class ISchedulerTaskInfo(Interface):
                            required=False,
                            vocabulary='ZTFY mail deliveries')
 
-    report_errors_only = Bool(title=_("Only report errors ?"),
-                              description=_("It 'Yes', only error reports will be sent to given target"),
+    report_errors_only = Bool(title=_("Only report errors?"),
+                              description=_("If 'Yes', only error reports will be sent to given target"),
+                              required=True,
+                              default=False)
+
+    send_empty_reports = Bool(title=_("Send empty reports?"),
+                              description=_("If 'No', empty reports will not be sent by mail"),
+                              required=True,
+                              default=False)
+
+    keep_empty_reports = Bool(title=_("Keep empty reports history?"),
+                              description=_("If 'Yes', empty reports will be kept in task history"),
                               required=True,
                               default=False)
 
